summaryrefslogtreecommitdiffstats
path: root/tderesources/kolab/kcal/resourcekolab.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tderesources/kolab/kcal/resourcekolab.cpp')
-rw-r--r--tderesources/kolab/kcal/resourcekolab.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tderesources/kolab/kcal/resourcekolab.cpp b/tderesources/kolab/kcal/resourcekolab.cpp
index 44c13fd2..50f8b5b8 100644
--- a/tderesources/kolab/kcal/resourcekolab.cpp
+++ b/tderesources/kolab/kcal/resourcekolab.cpp
@@ -37,8 +37,8 @@
#include "task.h"
#include "journal.h"
-#include <kio/observer.h>
-#include <kio/uiserver_stub.h>
+#include <tdeio/observer.h>
+#include <tdeio/uiserver_stub.h>
#include <kapplication.h>
#include <dcopclient.h>
#include <libtdepim/kincidencechooser.h>
@@ -172,8 +172,8 @@ bool ResourceKolab::loadSubResource( const TQString& subResource,
: i18n( "Loading events..." );
const bool useProgress = tqApp && tqApp->type() != TQApplication::Tty && count > mProgressDialogIncidenceLimit;
if ( useProgress )
- (void)::Observer::self(); // ensure kio_uiserver is running
- UIServer_stub uiserver( "kio_uiserver", "UIServer" );
+ (void)::Observer::self(); // ensure tdeio_uiserver is running
+ UIServer_stub uiserver( "tdeio_uiserver", "UIServer" );
int progressId = 0;
if ( useProgress ) {
progressId = uiserver.newJob( kapp->dcopClient()->appId(), true );